==> haskell-microstache-1.0.2.3-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-CNWKyl3Qqjt2NQZ7Kty7RS
key:                  microstache-1.0.2.3-CNWKyl3Qqjt2NQZ7Kty7RS
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  cc6d93ef21a2e67cccab1ed984051761
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-CNWKyl3Qqjt2NQZ7Kty7RS
depends:
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM
    vector-0.13.1.0-2w7Kefz4Viy7lxr9yJSbMz

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.2.3-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-PjCSjJkucIIxiclFLgbcF
key:                  microstache-1.0.2.3-PjCSjJkucIIxiclFLgbcF
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  51d04d0841b592875d4ec168d565a233
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-PjCSjJkucIIxiclFLgbcF
depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
